@@ -284,6 +284,7 @@ class ClUpdateAction(Action):
                             Get('cl_update_settings_changes_set') == 'on' or
                             Get('cl_update_binhost_recheck_set') == 'on' or
                             Get('cl_update_force_fix_set') == 'on' or
+                            Get('cl_update_available_set') == 'on' or
                             Get('update.cl_update_package_cache_set') == 'on')
              },
         {'name': 'update_other',
@@ -433,6 +434,10 @@ class ClUpdateAction(Action):
         {'name': 'update:save_portage_hash',
          'method': 'Update.save_portage_state_hash()',
          },
+        {'name': 'drop_portage_hash',
+         'method': 'Update.drop_portage_state_hash()',
+         'depend': Tasks.failed()
+         },
         # сообщение удачного завершения при обновлении ревизии
         {'name': 'success_rev',
          'message': __("System update finished!"),
